@@ -63,7 +63,7 @@ defined in `RFC 4013`_.
 
     def _process(self, value):
         for code in force_text(value):
-            #TODO: Is this long enough?
+            # TODO: Is this long enough?
             if stringprep.in_table_c12(code) or stringprep.in_table_c21_c22(code) or \
                 stringprep.in_table_c3(code) or stringprep.in_table_c4(code) or \
                 stringprep.in_table_c5(code) or stringprep.in_table_c6(code) or \
@@ -109,7 +109,7 @@ is greater than :py:attr:`~password_policies.conf.Settings.PASSWORD_MATCH_THRESH
         m, n = len(needle), len(haystack)
 
         if m == 1:
-            if not needle in haystack:
+            if needle not in haystack:
                 return -1
         if not n:
             return m
@@ -293,7 +293,7 @@ the Shannon entropy of a password.
             raise ValidationError(self.message, code=self.code)
 
     def entropy(self, string):
-        #Calculates the Shannon entropy of a string
+        # Calculates the Shannon entropy of a string
         #
         # get probability of chars in string
         prob = [float(string.count(c)) / len(string) for c in dict.fromkeys(list(string))]
@@ -302,7 +302,7 @@ the Shannon entropy of a password.
         return entropy
 
     def entropy_ideal(self, length):
-        #Calculates the ideal Shannon entropy of a string with given length
+        # Calculates the ideal Shannon entropy of a string with given length
         prob = 1.0 / length
         return -1.0 * length * prob * math.log(prob) / math.log(2.0)
 
